@@ -34,7 +34,7 @@ const (
 var TopDir string
 
 func existsDo(fdDep *os.File, cwd, pth string) (bool, error) {
-	if _, err := os.Stat(path.Join(cwd, pth)); err == nil {
+	if FileExists(path.Join(cwd, pth)) {
 		return true, nil
 	}
 	return false, ifcreate(fdDep, pth)
@@ -89,7 +89,7 @@ func findDo(fdDep *os.File, cwd, tgt string) (string, int, error) {
 		if dirAbs == TopDir {
 			break
 		}
-		if _, err = os.Stat(path.Join(dirAbs, RedoDir, TopFile)); err == nil {
+		if FileExists(path.Join(dirAbs, RedoDir, TopFile)) {
 			break
 		}
 		if dirAbs == dirAbsPrev {
