@@ -62,6 +62,7 @@ var (
 	Cwd       string
 	BuildUUID string
 	IsTopRedo bool // is it the top redo instance
+	UmaskCur  int
 )
 
 func mustSetenv(key string) {
@@ -134,6 +135,9 @@ func main() {
 	}
 	log.SetFlags(log.Lshortfile)
 
+	UmaskCur = syscall.Umask(0)
+	syscall.Umask(UmaskCur)
+
 	var err error
 	Cwd, err = os.Getwd()
 	if err != nil {
