@@ -126,7 +126,7 @@ func (e RunError) Error() string {
 }
 
 func mkdirs(pth string) error {
-	if _, err := os.Stat(pth); err == nil {
+	if FileExists(pth) {
 		return nil
 	}
 	return os.MkdirAll(pth, os.FileMode(0777))
@@ -156,18 +156,13 @@ func isModified(cwd, redoDir, tgt string) (bool, *Inode, string, error) {
 		if m["Type"] != DepTypeIfchange || m["Target"] != tgt {
 			continue
 		}
-		fd, err := os.Open(path.Join(cwd, tgt))
+		ourInode, err = inodeFromFileByPath(path.Join(cwd, tgt))
 		if err != nil {
 			if os.IsNotExist(err) {
 				return false, nil, "", nil
 			}
 			return false, nil, "", err
 		}
-		ourInode, err = inodeFromFile(fd)
-		fd.Close()
-		if err != nil {
-			return false, nil, "", err
-		}
 		theirInode, err := inodeFromRec(m)
 		if err != nil {
 			return false, nil, "", err
@@ -655,15 +650,12 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		}
 
 		// Was $1 touched?
-		if fd, err := os.Open(path.Join(cwdOrig, tgt)); err == nil {
+		if inode, err := inodeFromFileByPath(path.Join(cwdOrig, tgt)); err == nil {
 			if inodePrev == nil {
-				fd.Close()
 				runErr.Err = Err1WasTouched
 				errs <- runErr
 				return
 			}
-			inode, err := inodeFromFile(fd)
-			fd.Close()
 			if err != nil {
 				runErr.Err = err
 				errs <- runErr
@@ -677,10 +669,8 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		}
 
 		if inodePrev != nil {
-			if fd, err := os.Open(path.Join(cwdOrig, tgt)); err == nil {
-				inode, err := inodeFromFile(fd)
-				fd.Close()
-				if err == nil && !inode.Equals(inodePrev) {
+			if inode, err := inodeFromFileByPath(path.Join(cwdOrig, tgt)); err == nil {
+				if !inode.Equals(inodePrev) {
 					runErr.Err = Err1WasTouched
 					errs <- runErr
 					return
